# Modelling Problem: You throw a tennis ball horizontally at a 
# speed of 20 m/s off the top of a building which is 50 m tall. 
# Assuming no wind, but accounting for air resistance, how far 
# from the base of the building will the ball first hit the ground?
# last update Nov. 24, 2024 by Jason Harlow

# Import numpy, a library for scientific computing with python (so 
# you can use useful functions like sin, cos, etc.):
from numpy import *
# import plotting library to plot the trajectory:
import matplotlib.pyplot as plt

# You might want to graph the actual trajectory, so let's make
# a comma-separated text file you can read into excel
file = open('rangeOutput.csv', 'w')

### Properties of Earth ###
# The acceleration due to gravity [m/s^2]
g = 9.8

# The time-step of the numerical integration [s]
dt = 0.001

# Initial speed of the ball: [m/s]
v0 = 20

# Initial height of the ball [m]:
h0 = 50

t = 0
x = 0 
y = h0
vx = v0
vy = 0 
# You might want to graph the actual trajectory, so let's make a list to 
# store the x, y, and t values:
xs = []
ys = []
ts = []
while the ball is above the ground:
    # Find the acceleration:
    ax = 0
    ay = -1*g
    # Given the acceleration, update the velocity:
    vx = vx + (ax*dt)
    vy = vy + (ay*dt)
    # Given the velocity, update the position:
    x = x + (vx*dt)
    y = y + (vy*dt)
    # Update the time:
    t = t + dt
    # Output the trajectory to the screen:
    print("x = ",x,", y = ",y,", t = ",t)
    # Store the trajectory in lists:
    xs.append(x)
    ys.append(y)
    # Output the trajectory to a file:
    file.write(str(x))
    file.write(',')
    file.write(str(y))
    file.write(',')
    file.write(str(t))
    file.write('\n')

# plot the trajectory (x vs. y)
plt.figure(figsize=(6,6))
plt.plot(xs,ys)
plt.xlabel("x [m]") # label the x axis
plt.ylabel("y [m]") # label the y axis

file.close()
   

